==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/TaskRuntime.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) The runtime component of the tasks engine.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.448Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.TaskRuntime")
public class TaskRuntime extends software.amazon.jsii.JsiiObject {

    protected TaskRuntime(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TaskRuntime(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param workdir This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TaskRuntime(final @org.jetbrains.annotations.NotNull java.lang.String workdir) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(workdir, "workdir is required") });
    }

    /**
     * (experimental) Runs the task.
     * <p>
     * @param name The task name. This parameter is required.
     * @param parents
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void runTask(final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> parents) {
        software.amazon.jsii.Kernel.call(this, "runTask", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(name, "name is required"), parents });
    }

    /**
     * (experimental) Runs the task.
     * <p>
     * @param name The task name. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void runTask(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        software.amazon.jsii.Kernel.call(this, "runTask", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) Find a task by name, or `undefined` if not found.
     * <p>
     * @param name This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.TaskSpec tryFindTask(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.Kernel.call(this, "tryFindTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.TaskSpec.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) The contents of tasks.json.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.TasksManifest getManifest() {
        return software.amazon.jsii.Kernel.get(this, "manifest", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.TasksManifest.class));
    }

    /**
     * (experimental) The tasks in this project.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<io.github.cdklabs.projen.TaskSpec> getTasks() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "tasks", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.TaskSpec.class))));
    }

    /**
     * (experimental) The root directory of the project and the cwd for executing tasks.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getWorkdir() {
        return software.amazon.jsii.Kernel.get(this, "workdir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/TaskRuntime.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) The runtime component of the tasks engine.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.156Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.TaskRuntime")
public class TaskRuntime extends software.amazon.jsii.JsiiObject {

    protected TaskRuntime(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TaskRuntime(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        MANIFEST_FILE = software.amazon.jsii.JsiiObject.jsiiStaticGet(io.github.cdklabs.projen.TaskRuntime.class, "MANIFEST_FILE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * @param workdir This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public TaskRuntime(final @org.jetbrains.annotations.NotNull java.lang.String workdir) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(workdir, "workdir is required") });
    }

    /**
     * (experimental) Runs the task.
     * <p>
     * @param name The task name. This parameter is required.
     * @param parents
     * @param args
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void runTask(final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> parents, final @org.jetbrains.annotations.Nullable java.util.List<java.lang.Object> args) {
        if (software.amazon.jsii.Configuration.getRuntimeTypeChecking()) {
            for (int __idx_5a3d9f = 0; __idx_5a3d9f < args.size(); __idx_5a3d9f++) {
                final java.lang.Object __val_5a3d9f = args.get(__idx_5a3d9f);
                if (
                     !(__val_5a3d9f instanceof java.lang.String)
                    && !(__val_5a3d9f instanceof java.lang.Number)
                ) {
                    throw new IllegalArgumentException(
                        new java.lang.StringBuilder("Expected ")
                            .append("args").append(".get(").append(__idx_5a3d9f).append(")")
                            .append(" to be one of: java.lang.String, java.lang.Number; received ")
                            .append(__val_5a3d9f.getClass()).toString());
                }
            }
        }
        software.amazon.jsii.Kernel.call(this, "runTask", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(name, "name is required"), parents, args });
    }

    /**
     * (experimental) Runs the task.
     * <p>
     * @param name The task name. This parameter is required.
     * @param parents
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void runTask(final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> parents) {
        software.amazon.jsii.Kernel.call(this, "runTask", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(name, "name is required"), parents });
    }

    /**
     * (experimental) Runs the task.
     * <p>
     * @param name The task name. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void runTask(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        software.amazon.jsii.Kernel.call(this, "runTask", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) Find a task by name, or <code>undefined</code> if not found.
     * <p>
     * @param name This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.TaskSpec tryFindTask(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.Kernel.call(this, "tryFindTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.TaskSpec.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * (experimental) The project-relative path of the tasks manifest file.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static java.lang.String MANIFEST_FILE;

    /**
     * (experimental) The contents of tasks.json.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.TasksManifest getManifest() {
        return software.amazon.jsii.Kernel.get(this, "manifest", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.TasksManifest.class));
    }

    /**
     * (experimental) The tasks in this project.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<io.github.cdklabs.projen.TaskSpec> getTasks() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "tasks", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.TaskSpec.class))));
    }

    /**
     * (experimental) The root directory of the project and the cwd for executing tasks.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getWorkdir() {
        return software.amazon.jsii.Kernel.get(this, "workdir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }
}
